Changes
=======

0.3.0 (2013-07-16)
------------------

- Fix XSS vulnerability
- Allow relatives/includes/fieldset.html template to be extended further
- Improve documentation


0.2.0 (2013-06-26)
------------------

- Add related_objects template tag
- Fix contents_or_fk_link filter on add form for non-nullable foreign keys
- Rename edit_link utility function to object_link
- Add generic object_edit_link utility
- Add generic templates for easy related_objects and contents_or_fk_link use


0.1.0 (2013-05-17)
------------------
Initial release.
